@@ -39,6 +39,14 @@
 
 #include <string.h>
 
+/**
+ * SECTION:ephy-location-entry
+ * @short_description: A location entry widget
+ * @see_also: #GtkEntry
+ *
+ * #EphyLocationEntry implements the location bar in the main Epiphany window.
+ */
+
 #define EPHY_LOCATION_ENTRY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_LOCATION_ENTRY, EphyLocationEntryPrivate))
 
 struct _EphyLocationEntryPrivate
@@ -128,7 +136,7 @@ ephy_location_entry_style_set (GtkWidget *widget,
 		GTK_WIDGET_CLASS (ephy_location_entry_parent_class)->style_set (widget, previous_style);
 	}
 
-	title_fg_colour = widget->style->text[GTK_STATE_INSENSITIVE];
+	title_fg_colour = gtk_widget_get_style (widget)->text[GTK_STATE_INSENSITIVE];
 
 	settings = gtk_settings_get_for_screen (gtk_widget_get_screen (widget));
 	g_object_get (settings, "gtk-theme-name", &theme, NULL);
@@ -186,6 +194,7 @@ ephy_location_entry_finalize (GObject *object)
 	EphyLocationEntryPrivate *priv = entry->priv;
 	
 	g_free (priv->saved_text);
+	g_free (priv->lock_stock_id);
 
 	if (priv->favicon != NULL)
 	{
@@ -211,6 +220,13 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 
 	widget_class->style_set = ephy_location_entry_style_set;
 
+    /**
+	* EphyLocationEntry::user-changed:
+	* @entry: the object on which the signal is emitted
+	*
+	* Emitted when the user changes the contents of the internal #GtkEntry
+	*
+	*/
 	signals[USER_CHANGED] = g_signal_new (
 		"user_changed", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -221,6 +237,14 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		0,
 		G_TYPE_NONE);
 
+    /**
+	* EphyLocationEntry::lock-clicked:
+	* @entry: the object on which the signal is emitted
+	*
+	* Emitted when the user clicks the security icon inside the
+	* #EphyLocationEntry.
+	*
+	*/
 	signals[LOCK_CLICKED] = g_signal_new (
 		"lock-clicked",
 		EPHY_TYPE_LOCATION_ENTRY,
@@ -231,6 +255,16 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		G_TYPE_NONE,
 		0);
 
+    /**
+	* EphyLocationEntry::get-location:
+	* @entry: the object on which the signal is emitted
+	* Returns: the current page address as a string
+	*
+	* For drag and drop purposes, the location bar will request you the real
+	* address of where it is pointing to. The signal handler for this function
+	* should return the address of the currently loaded site.
+	*
+	*/
 	signals[GET_LOCATION] = g_signal_new (
 		"get-location", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -241,6 +275,16 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		0,
 		G_TYPE_NONE);
 
+    /**
+	* EphyLocationEntry::get-title:
+	* @entry: the object on which the signal is emitted
+	* Returns: the current page title as a string
+	*
+	* For drag and drop purposes, the location bar will request you the title
+	* of where it is pointing to. The signal handler for this function
+	* should return the title of the currently loaded site.
+	*
+	*/
 	signals[GET_TITLE] = g_signal_new (
 		"get-title", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -458,7 +502,7 @@ entry_key_press_after_cb (GtkEntry *entry,
 	    (state == GDK_CONTROL_MASK ||
 	     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)))
 	{
-		gtk_im_context_reset (entry->im_context);
+		//gtk_im_context_reset (entry->im_context);
 
 		priv->needs_reset = TRUE;
 		g_signal_emit_by_name (entry, "activate");
@@ -518,8 +562,8 @@ match_selected_cb (GtkEntryCompletion *completion,
 	priv->needs_reset = (state == GDK_CONTROL_MASK ||
 			     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK));
 
-	ephy_location_entry_set_location (entry, item, NULL);
-	gtk_im_context_reset (GTK_ENTRY (entry->priv->entry)->im_context);
+	ephy_location_entry_set_location (entry, item);
+	//gtk_im_context_reset (GTK_ENTRY (entry->priv->entry)->im_context);
 	g_signal_emit_by_name (priv->entry, "activate");
 
 	g_free (item);
@@ -647,7 +691,7 @@ entry_populate_popup_cb (GtkEntry *entry,
 	 * menu, and insert this menu item before it.
 	 * It's a bit of a hack, but there seems to be no better way to do it :/
 	 */
-	children = GTK_MENU_SHELL (menu)->children;
+	children = gtk_container_get_children (GTK_CONTAINER (menu));
 	for (item = children; item != NULL && sep < 2; item = item->next, pos++)
 	{
 		if (GTK_IS_SEPARATOR_MENU_ITEM (item->data)) sep++;
@@ -703,6 +747,7 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	EphyLocationEntryPrivate *priv = entry->priv;
 	char *title = NULL, *address = NULL;
 	GString *text;
+	GtkStyle *style;
 	GdkDrawable *drawable;
 	PangoContext *context;
 	PangoLayout  *layout;
@@ -743,8 +788,9 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	layout = pango_layout_new (context);
 
 	context = gtk_widget_get_pango_context (widget);
+	style = gtk_widget_get_style (widget);
 	metrics = pango_context_get_metrics (context,
-					     widget->style->font_desc,
+					     style->font_desc,
 					     pango_context_get_language (context));
 
 	char_width = pango_font_metrics_get_approximate_digit_width (metrics);
@@ -769,13 +815,13 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 		pixmap_height = layout_height / PANGO_SCALE + DRAG_ICON_LAYOUT_BORDER * 2;
 	}
 
-	drawable = gdk_pixmap_new (widget->window,
+	drawable = gdk_pixmap_new (gtk_widget_get_window (widget),
 				   pixmap_width  + 2,
 				   pixmap_height + 2,
 				   -1);
 
 	gdk_draw_rectangle (drawable,
-			    widget->style->base_gc [GTK_WIDGET_STATE (widget)],
+			    style->base_gc [gtk_widget_get_state (widget)],
 			    TRUE,
 			    0, 0,
 			    pixmap_width + 1,
@@ -785,7 +831,7 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	if (priv->favicon != NULL)
 	{
 		gdk_draw_pixbuf (drawable,
-				 widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+				 style->fg_gc[gtk_widget_get_state (widget)],
 				 priv->favicon,
 				 0, 0, 
 				 1 + DRAG_ICON_LAYOUT_BORDER + DRAG_ICON_ICON_SPACING,
@@ -795,13 +841,13 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	}
 
 	gdk_draw_layout (drawable,
-			 widget->style->text_gc [GTK_WIDGET_STATE (widget)],
+			 style->text_gc [gtk_widget_get_state (widget)],
 			 1 + DRAG_ICON_LAYOUT_BORDER + offset_x,
 			 1 + DRAG_ICON_LAYOUT_BORDER,
 			 layout);
 
 	gdk_draw_rectangle (drawable,
-			    widget->style->black_gc,
+			    style->black_gc,
 			    FALSE,
 			    0, 0,
 			    pixmap_width + 1,
@@ -1207,6 +1253,9 @@ ephy_location_entry_set_completion (EphyLocationEntry *entry,
 	g_signal_connect_after (completion, "action-activated",
 				G_CALLBACK (action_activated_after_cb), entry);
 
+	/* FIXME: this works fine, but the favicons seem to be
+	 * added-removed the view constantly, and the visual effect is
+	 * very ugly */
 #if 0
 	cell = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
@@ -1259,18 +1308,13 @@ ephy_location_entry_set_completion (EphyLocationEntry *entry,
 /**
  * ephy_location_entry_set_location:
  * @entry: an #EphyLocationEntry widget
- * @address: the address to be set as the current location
- * @typed_address: the address to be shown in the location entry or NULL
- *
- * Sets the current address of @entry to @address, alternatively a
- * @typed_address can be used to determine the text to be displayed in the
- * location entry.
+ * @address: new location address
  *
+ * Sets the current address of @entry to @address.
  **/
 void
 ephy_location_entry_set_location (EphyLocationEntry *entry,
-				  const char *address,
-				  const char *typed_address)
+				  const char *address)
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 	GtkClipboard *clipboard;
@@ -1278,14 +1322,12 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 	char* selection = NULL;
 	int start, end;
 
-	g_return_if_fail (address != NULL);
-
 	/* Setting a new text will clear the clipboard. This makes it impossible
 	 * to copy&paste from the location entry of one tab into another tab, see
 	 * bug #155824. So we save the selection iff the clipboard was owned by
 	 * the location entry.
 	 */
-	if (GTK_WIDGET_REALIZED (GTK_WIDGET (priv->entry)))
+	if (gtk_widget_get_realized (GTK_WIDGET (priv->entry)))
 	{
 		clipboard = gtk_widget_get_clipboard (priv->entry,
 						      GDK_SELECTION_PRIMARY);
@@ -1300,11 +1342,7 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 		}
 	}
 
-	if (typed_address != NULL)
-	{
-		text = typed_address;
-	}
-	else if (address != NULL && strcmp (address, "about:blank") != 0)
+	if (address != NULL && strcmp (address, "about:blank") != 0)
 	{
 		text = address;
 	}
@@ -1314,7 +1352,7 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 	}
 
 	/* First record the new hash, then update the entry text */
-	priv->hash = g_str_hash (address);
+	priv->hash = g_str_hash (text);
 
 	priv->block_update = TRUE;
 	gtk_entry_set_text (GTK_ENTRY (priv->entry), text);
@@ -1410,7 +1448,7 @@ ephy_location_entry_reset_internal (EphyLocationEntry *entry,
 
 	retval = g_str_hash (text) != g_str_hash (old_text);
 
-	ephy_location_entry_set_location (entry, text, NULL);
+	ephy_location_entry_set_location (entry, text);
 	g_free (url);
 
 	if (notify)
@@ -1601,7 +1639,7 @@ ephy_location_entry_set_lock_stock (EphyLocationEntry *entry,
 {
 	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
 
-	entry->priv->lock_stock_id = (char*)stock_id;
+	entry->priv->lock_stock_id = g_strdup (stock_id);
 
 	if (entry->priv->show_lock)
 		gtk_entry_set_icon_from_stock (GTK_ENTRY (entry->priv->entry),
